@@ -10,9 +10,9 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.5.12"
-#define MARIADB_BASE_VERSION		"mariadb-10.5"
-#define MARIADB_VERSION_ID		100512
+#define MARIADB_CLIENT_VERSION_STR	"10.6.4"
+#define MARIADB_BASE_VERSION		"mariadb-10.6"
+#define MARIADB_VERSION_ID		100604
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/var/run/mysql/mysql.sock"
 #ifndef MYSQL_UNIX_ADDR
@@ -23,13 +23,13 @@
 #endif
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                100512
-#define MYSQL_SERVER_VERSION            "10.5.12-MariaDB"
+#define MYSQL_VERSION_ID                100604
+#define MYSQL_SERVER_VERSION            "10.6.4-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.1.14"
-#define MARIADB_PACKAGE_VERSION_ID 30114
+#define MARIADB_PACKAGE_VERSION "3.2.4"
+#define MARIADB_PACKAGE_VERSION_ID 30204
 #define MARIADB_SYSTEM_TYPE "OpenBSD"
-#define MARIADB_MACHINE_TYPE "amd64"
+#define MARIADB_MACHINE_TYPE "arm"
 #define MARIADB_PLUGINDIR "/usr/local/lib/mysql/plugin"
 
 /* mysqld compile time options */
